<?php
/**
 * Service Section
 *
 * @package Corporaze
 */

$wp_customize->add_section(
	'corporaze_service_section',
	array(
		'panel'    => 'corporaze_front_page_options',
		'title'    => esc_html__( 'Service Section', 'corporaze' ),
		'priority' => 30,
	)
);

// Service Section - Enable Section.
$wp_customize->add_setting(
	'corporaze_enable_service_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'corporaze_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Corporaze_Toggle_Switch_Custom_Control(
		$wp_customize,
		'corporaze_enable_service_section',
		array(
			'label'    => esc_html__( 'Enable Service Section', 'corporaze' ),
			'section'  => 'corporaze_service_section',
			'settings' => 'corporaze_enable_service_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'corporaze_enable_service_section',
		array(
			'selector' => '#corporaze_service_section .section-link',
			'settings' => 'corporaze_enable_service_section',
		)
	);
}

// Service Section - Section Title.
$wp_customize->add_setting(
	'corporaze_service_title',
	array(
		'default'           => __( 'Our Services', 'corporaze' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'corporaze_service_title',
	array(
		'label'           => esc_html__( 'Section Title', 'corporaze' ),
		'section'         => 'corporaze_service_section',
		'settings'        => 'corporaze_service_title',
		'type'            => 'text',
		'active_callback' => 'corporaze_is_service_section_enabled',
	)
);

// Service Section - Section Text.
$wp_customize->add_setting(
	'corporaze_service_text',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'corporaze_service_text',
	array(
		'label'           => esc_html__( 'Section Text', 'corporaze' ),
		'section'         => 'corporaze_service_section',
		'settings'        => 'corporaze_service_text',
		'type'            => 'text',
		'active_callback' => 'corporaze_is_service_section_enabled',
	)
);

// Service Section - Posts Button Label.
$wp_customize->add_setting(
	'corporaze_service_posts_button_label',
	array(
		'default'           => __( 'View Detail', 'corporaze' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'corporaze_service_posts_button_label',
	array(
		'label'           => esc_html__( 'Posts Button Label', 'corporaze' ),
		'section'         => 'corporaze_service_section',
		'settings'        => 'corporaze_service_posts_button_label',
		'type'            => 'text',
		'active_callback' => 'corporaze_is_service_section_enabled',
	)
);

// Service Section - Content Type.
$wp_customize->add_setting(
	'corporaze_service_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'corporaze_sanitize_select',
	)
);

$wp_customize->add_control(
	'corporaze_service_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'corporaze' ),
		'section'         => 'corporaze_service_section',
		'settings'        => 'corporaze_service_content_type',
		'type'            => 'select',
		'active_callback' => 'corporaze_is_service_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'corporaze' ),
			'post' => esc_html__( 'Post', 'corporaze' ),
		),
	)
);

for ( $i = 1; $i <= 3; $i++ ) {

	// Service Section - Custom Icon.
	$wp_customize->add_setting(
		'corporaze_service_icon_' . $i,
		array(
			'sanitize_callback' => 'corporaze_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'corporaze_service_icon_' . $i,
			array(
				'label'           => sprintf( esc_html__( 'Custom Icon %d', 'corporaze' ), $i ),
				'section'         => 'corporaze_service_section',
				'settings'        => 'corporaze_service_icon_' . $i,
				'active_callback' => 'corporaze_is_service_section_enabled',
			)
		)
	);

	// Service Section - Select Post.
	$wp_customize->add_setting(
		'corporaze_service_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'corporaze_service_content_post_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Post %d', 'corporaze' ), $i ),
			'section'         => 'corporaze_service_section',
			'settings'        => 'corporaze_service_content_post_' . $i,
			'active_callback' => 'corporaze_is_service_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => corporaze_get_post_choices(),
		)
	);

	// Service Section - Select Page.
	$wp_customize->add_setting(
		'corporaze_service_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'corporaze_service_content_page_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Page %d', 'corporaze' ), $i ),
			'section'         => 'corporaze_service_section',
			'settings'        => 'corporaze_service_content_page_' . $i,
			'active_callback' => 'corporaze_is_service_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => corporaze_get_page_choices(),
		)
	);

}

// Service Section - Button Label.
$wp_customize->add_setting(
	'corporaze_service_button_label',
	array(
		'default'           => __( 'View All Services', 'corporaze' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'corporaze_service_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'corporaze' ),
		'section'         => 'corporaze_service_section',
		'settings'        => 'corporaze_service_button_label',
		'type'            => 'text',
		'active_callback' => 'corporaze_is_service_section_enabled',
	)
);

// Service Section - Button Link.
$wp_customize->add_setting(
	'corporaze_service_button_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'corporaze_service_button_link',
	array(
		'label'           => esc_html__( 'Button Link', 'corporaze' ),
		'section'         => 'corporaze_service_section',
		'settings'        => 'corporaze_service_button_link',
		'type'            => 'url',
		'active_callback' => 'corporaze_is_service_section_enabled',
	)
);
