<?php
/**
 * Team Section
 *
 * @package Corporaze
 */

$wp_customize->add_section(
	'corporaze_team_section',
	array(
		'panel'    => 'corporaze_front_page_options',
		'title'    => esc_html__( 'Team Section', 'corporaze' ),
		'priority' => 60,
	)
);

// Team Section - Enable Section.
$wp_customize->add_setting(
	'corporaze_enable_team_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'corporaze_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Corporaze_Toggle_Switch_Custom_Control(
		$wp_customize,
		'corporaze_enable_team_section',
		array(
			'label'    => esc_html__( 'Enable Team Section', 'corporaze' ),
			'section'  => 'corporaze_team_section',
			'settings' => 'corporaze_enable_team_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'corporaze_enable_team_section',
		array(
			'selector' => '#corporaze_team_section .section-link',
			'settings' => 'corporaze_enable_team_section',
		)
	);
}

// Team Section - Section Title.
$wp_customize->add_setting(
	'corporaze_team_section_title',
	array(
		'default'           => __( 'Our Team', 'corporaze' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'corporaze_team_section_title',
	array(
		'label'           => esc_html__( 'Section Title', 'corporaze' ),
		'section'         => 'corporaze_team_section',
		'settings'        => 'corporaze_team_section_title',
		'type'            => 'text',
		'active_callback' => 'corporaze_is_team_section_enabled',
	)
);

// Team Section - Section Text.
$wp_customize->add_setting(
	'corporaze_team_section_text',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'corporaze_team_section_text',
	array(
		'label'           => esc_html__( 'Section Text', 'corporaze' ),
		'section'         => 'corporaze_team_section',
		'settings'        => 'corporaze_team_section_text',
		'type'            => 'text',
		'active_callback' => 'corporaze_is_team_section_enabled',
	)
);

// Team Section - Content Type.
$wp_customize->add_setting(
	'corporaze_team_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'corporaze_sanitize_select',
	)
);

$wp_customize->add_control(
	'corporaze_team_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'corporaze' ),
		'section'         => 'corporaze_team_section',
		'settings'        => 'corporaze_team_content_type',
		'type'            => 'select',
		'active_callback' => 'corporaze_is_team_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'corporaze' ),
			'post' => esc_html__( 'Post', 'corporaze' ),
		),
	)
);

for ( $i = 1; $i <= 3; $i++ ) {

	// Team Section - Select Post.
	$wp_customize->add_setting(
		'corporaze_team_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'corporaze_team_content_post_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Post %d', 'corporaze' ), $i ),
			'section'         => 'corporaze_team_section',
			'settings'        => 'corporaze_team_content_post_' . $i,
			'active_callback' => 'corporaze_is_team_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => corporaze_get_post_choices(),
		)
	);

	// Team Section - Select Page.
	$wp_customize->add_setting(
		'corporaze_team_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'corporaze_team_content_page_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Page %d', 'corporaze' ), $i ),
			'section'         => 'corporaze_team_section',
			'settings'        => 'corporaze_team_content_page_' . $i,
			'active_callback' => 'corporaze_is_team_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => corporaze_get_page_choices(),
		)
	);

	// Team Section - Designation.
	$wp_customize->add_setting(
		'corporaze_team_designation_' . $i,
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'corporaze_team_designation_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Designation %d', 'corporaze' ), $i ),
			'section'         => 'corporaze_team_section',
			'settings'        => 'corporaze_team_designation_' . $i,
			'active_callback' => 'corporaze_is_team_section_enabled',
		)
	);

	// Team Section - Social Links.
	$wp_customize->add_setting(
		'corporaze_team_social_links_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$wp_customize->add_control(
		new Corporaze_Sortable_Repeater_Custom_Control(
			$wp_customize,
			'corporaze_team_social_links_' . $i,
			array(
				'label'           => sprintf( esc_html__( 'Social Icons %d', 'corporaze' ), $i ),
				'section'         => 'corporaze_team_section',
				'button_labels'   => array(
					'add' => __( 'Add', 'corporaze' ),
				),
				'active_callback' => 'corporaze_is_team_section_enabled',
			)
		)
	);
}

// Team Section - Button Label.
$wp_customize->add_setting(
	'corporaze_team_button_label',
	array(
		'default'           => __( 'View All', 'corporaze' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'corporaze_team_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'corporaze' ),
		'section'         => 'corporaze_team_section',
		'settings'        => 'corporaze_team_button_label',
		'type'            => 'text',
		'active_callback' => 'corporaze_is_team_section_enabled',
	)
);

// Team Section - Button Link.
$wp_customize->add_setting(
	'corporaze_team_button_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'corporaze_team_button_link',
	array(
		'label'           => esc_html__( 'Button Link', 'corporaze' ),
		'section'         => 'corporaze_team_section',
		'settings'        => 'corporaze_team_button_link',
		'type'            => 'url',
		'active_callback' => 'corporaze_is_team_section_enabled',
	)
);
